@@ -1,6 +1,8 @@
 use algebr::Vec2;
 
-use crate::{style::Style, Rect, Shape, ShapeType};
+use crate::{shapes::path::Keypoint, style::Style, Rect, Shape, ShapeType};
+
+use super::path::Keypoints;
 
 pub type Line = LineBuilder<true>;
 
@@ -47,3 +49,9 @@ impl Into<Shape> for LineBuilder<true> {
         }
     }
 }
+
+impl Into<Keypoints> for LineBuilder<true> {
+    fn into(self) -> Keypoints {
+        Keypoints(vec![Keypoint::Point(self.from), Keypoint::Point(self.to)])
+    }
+}
